@@ -15,7 +15,6 @@ class KEduVocDocument;
 
 namespace Editor
 {
-
 class ConjugationWidget : public QWidget, public Ui::ConjugationWidget
 {
     Q_OBJECT
@@ -24,14 +23,14 @@ public:
     explicit ConjugationWidget(QWidget *parent = 0);
 
 public slots:
-    void setDocument(KEduVocDocument* doc);
-    void setTranslation(KEduVocExpression* entry, int translation);
+    void setDocument(KEduVocDocument *doc);
+    void setTranslation(KEduVocExpression *entry, int translation);
 
 signals:
     void sigModified();
 
 private slots:
-    void textChanged(const QString&);
+    void textChanged(const QString &);
     void slotTenseSelected(int);
     void slotNextTense();
     void tenseEditingFinished();
@@ -47,14 +46,14 @@ private:
     void updateEntries();
 
     QString m_lastTenseSelection;
-    int m_identifier;
-    KEduVocExpression* m_entry;
-    KEduVocDocument* m_doc;
+    int m_identifier{-1};
+    KEduVocExpression *m_entry{nullptr};
+    KEduVocDocument *m_doc{nullptr};
 
     /**
      * All line edits and labels, index corresponding to KEduVocWordFlag::indexOf
      */
-    QMap< KEduVocWordFlags, QLineEdit* > m_conjugationLineEdits;
+    QMap<KEduVocWordFlags, QLineEdit *> m_conjugationLineEdits;
 };
 
 }
