@@ -19,19 +19,18 @@ class QStringListModel;
 
 namespace Editor
 {
-
 class MultipleChoiceWidget : public QWidget, public Ui::multipleChoiceWidget
 {
     Q_OBJECT
 
 public:
-    explicit MultipleChoiceWidget(QWidget *parent = 0);
+    explicit MultipleChoiceWidget(QWidget *parent = nullptr);
 
 public slots:
     void setTranslation(KEduVocExpression *entry, int translation);
 
 protected:
-    bool eventFilter(QObject *obj, QEvent *event) Q_DECL_OVERRIDE;
+    bool eventFilter(QObject *obj, QEvent *event) override;
 
 private slots:
     void slotDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
@@ -39,8 +38,8 @@ private slots:
     void slotRemoveChoiceButton();
 
 private:
-    KEduVocTranslation *m_translation;
-    QStringListModel *m_choicesModel;
+    KEduVocTranslation *m_translation{nullptr};
+    QStringListModel *m_choicesModel{nullptr};
 };
 }
 
