@@ -7,9 +7,9 @@
 #ifndef CONFIGUREPRACTICEDIALOG_H
 #define CONFIGUREPRACTICEDIALOG_H
 
-#include <KEduVocDocument>
-#include <KConfigWidgets/KConfigDialog>
 #include <KConfigSkeleton>
+#include <KConfigWidgets/KConfigDialog>
+#include <KEduVocDocument>
 
 class GeneralPracticeOptions;
 class SpecificPracticeOptions;
@@ -17,8 +17,8 @@ class ThresholdOptions;
 class BlockOptions;
 
 /**
-  *
-  */
+ *
+ */
 class ConfigurePracticeDialog : public KConfigDialog
 {
     Q_OBJECT
@@ -26,7 +26,7 @@ class ConfigurePracticeDialog : public KConfigDialog
 public:
     ConfigurePracticeDialog(KEduVocDocument *doc, QWidget *parent, const QString &name, KConfigSkeleton *config);
 
-    ~ConfigurePracticeDialog();
+    ~ConfigurePracticeDialog() override;
 
     void commitData();
 
@@ -34,35 +34,34 @@ private slots:
     /**
      * Called when the user clicks Apply or OK.
      */
-    void updateSettings() Q_DECL_OVERRIDE;
+    void updateSettings() override;
     /**
      * Updates dialog widgets. Here only used after loading a profile.
      * Profiles only store the settings of the last three pages in the dialog.
      */
-    void updateWidgets() Q_DECL_OVERRIDE;
+    void updateWidgets() override;
     /**
      * Called when the user clicks Default
      */
-    void updateWidgetsDefault() Q_DECL_OVERRIDE;
+    void updateWidgetsDefault() override;
 
     /**
      * Returns true if the current state of the dialog is different from the saved settings
      */
-    bool hasChanged() Q_DECL_OVERRIDE;
+    bool hasChanged() override;
 
 private:
-
     /**
      * Returns true if the current state of the dialog represents the default settings.
      */
-    bool isDefault() Q_DECL_OVERRIDE;
+    bool isDefault() override;
 
-    GeneralPracticeOptions  *m_generalPracticeOptions;
-    BlockOptions            *m_blockOptions;
-    ThresholdOptions        *m_thresholdOptions;
-    SpecificPracticeOptions *m_specificPracticeOptions;
+    GeneralPracticeOptions *m_generalPracticeOptions{nullptr};
+    BlockOptions *m_blockOptions{nullptr};
+    ThresholdOptions *m_thresholdOptions{nullptr};
+    SpecificPracticeOptions *m_specificPracticeOptions{nullptr};
 
-    KConfigSkeleton *m_config;
+    KConfigSkeleton *m_config{nullptr};
 };
 
 #endif // ConfigurePracticeDialog_included
