@@ -8,8 +8,6 @@
 
 #include "writtenpracticewidget.h"
 
-#include <KRandomSequence>
-
 namespace Ui
 {
 class WrittenPracticeWidget;
@@ -17,7 +15,6 @@ class WrittenPracticeWidget;
 
 namespace Practice
 {
-
 class MixedLettersModeWidget : public Practice::WrittenPracticeWidget
 {
     Q_OBJECT
@@ -25,12 +22,12 @@ class MixedLettersModeWidget : public Practice::WrittenPracticeWidget
 public:
     explicit MixedLettersModeWidget(GuiFrontend *frontend, QWidget *parent = 0);
 
-    void setQuestion(const QVariant& question) Q_DECL_OVERRIDE;
-    void setSolution(const QVariant& solution) Q_DECL_OVERRIDE;
-    void setSolutionFont(const QFont& font) Q_DECL_OVERRIDE;
+    void setQuestion(const QVariant &question) override;
+    void setSolution(const QVariant &solution) override;
+    void setSolutionFont(const QFont &font) override;
 
 public slots:
-    void showQuestion() Q_DECL_OVERRIDE;
+    void showQuestion() override;
 
 private slots:
     void updatePixmap();
@@ -41,7 +38,6 @@ private:
     QString m_question;
     QList<int> m_positions;
     QPixmap m_pixmap;
-    KRandomSequence m_randomSequence;
     QFont m_solutionFont;
 };
 
